==> jc-1.4.0.tar.gz: java/security/UnresolvedPermissionCollection.h <==
// class java.security.UnresolvedPermissionCollection

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c66c17eff6c1d1e6 java_security_PermissionCollection
// @dep_class 5dd1d1276c582d70 java_security_UnresolvedPermissionCollection

// header file dependencies
// @dep_header java_security_PermissionCollection

#include "java/security/PermissionCollection.h"

#ifndef _JC_java_security_UnresolvedPermissionCollection_H_
#define _JC_java_security_UnresolvedPermissionCollection_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_Permission$object;
struct _jc_java_util_Enumeration$object;
struct _jc_java_util_Hashtable$object;

// Typedefs
typedef struct _jc_java_security_UnresolvedPermissionCollection$sub_refs	_jc_java_security_UnresolvedPermissionCollection$sub_refs;
typedef struct _jc_java_security_UnresolvedPermissionCollection$sub_nonrefs	_jc_java_security_UnresolvedPermissionCollection$sub_nonrefs;
typedef struct _jc_java_security_UnresolvedPermissionCollection$refs	_jc_java_security_UnresolvedPermissionCollection$refs;
typedef struct _jc_java_security_UnresolvedPermissionCollection$nonrefs	_jc_java_security_UnresolvedPermissionCollection$nonrefs;
typedef struct _jc_java_security_UnresolvedPermissionCollection$object	_jc_java_security_UnresolvedPermissionCollection$object;

typedef struct _jc_java_security_UnresolvedPermissionCollection$fields_struct	_jc_java_security_UnresolvedPermissionCollection$fields_struct;
typedef const struct _jc_java_security_UnresolvedPermissionCollection$vmethods	_jc_java_security_UnresolvedPermissionCollection$vmethods;
typedef const struct _jc_java_security_UnresolvedPermissionCollection$vtable	_jc_java_security_UnresolvedPermissionCollection$vtable;
typedef const struct _jc_java_security_UnresolvedPermissionCollection$vtype	_jc_java_security_UnresolvedPermissionCollection$vtype;

// Class fields structure
struct _jc_java_security_UnresolvedPermissionCollection$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_UnresolvedPermissionCollection$fields_struct _jc_java_security_UnresolvedPermissionCollection$class_fields;

// Constructors
extern void _jc_java_security_UnresolvedPermissionCollection$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_UnresolvedPermissionCollection$object *);

// Virtual methods
extern void _jc_java_security_UnresolvedPermissionCollection$method$add$a94198a5fd6a54ee(_jc_env *, struct _jc_java_security_UnresolvedPermissionCollection$object *, struct _jc_java_security_Permission$object *);
extern struct _jc_object *_jc_java_security_UnresolvedPermissionCollection$method$elements$7e4aa0c44b86c479(_jc_env *, struct _jc_java_security_UnresolvedPermissionCollection$object *);
extern jboolean _jc_java_security_UnresolvedPermissionCollection$method$implies$cbacf9d54b2bb917(_jc_env *, struct _jc_java_security_UnresolvedPermissionCollection$object *, struct _jc_java_security_Permission$object *);
extern void _jc_java_security_UnresolvedPermissionCollection$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_security_UnresolvedPermissionCollection$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_UnresolvedPermissionCollection$method_info$add$a94198a5fd6a54ee;
extern _jc_method _jc_java_security_UnresolvedPermissionCollection$method_info$elements$7e4aa0c44b86c479;
extern _jc_method _jc_java_security_UnresolvedPermissionCollection$method_info$implies$cbacf9d54b2bb917;
extern _jc_method _jc_java_security_UnresolvedPermissionCollection$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_security_UnresolvedPermissionCollection$vmethods {
	void	(*add$a94198a5fd6a54ee)(_jc_env *, struct _jc_java_security_UnresolvedPermissionCollection$object *, struct _jc_java_security_Permission$object *);
	struct _jc_object	*(*elements$7e4aa0c44b86c479)(_jc_env *, struct _jc_java_security_UnresolvedPermissionCollection$object *);
	jboolean	(*implies$cbacf9d54b2bb917)(_jc_env *, struct _jc_java_security_UnresolvedPermissionCollection$object *, struct _jc_java_security_Permission$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_security_UnresolvedPermissionCollection$object *);
};

// Vtable
struct _jc_java_security_UnresolvedPermissionCollection$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_PermissionCollection$vmethods	java_security_PermissionCollection;
	_jc_java_security_UnresolvedPermissionCollection$vmethods	java_security_UnresolvedPermissionCollection;
};

// Vtype
struct _jc_java_security_UnresolvedPermissionCollection$vtype {
	_jc_type			type;
	_jc_java_security_UnresolvedPermissionCollection$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_UnresolvedPermissionCollection$sub_refs {
	struct _jc_java_util_Hashtable$object	*permissions;
};

// Reference instance fields (object)
struct _jc_java_security_UnresolvedPermissionCollection$refs {
    _jc_java_security_UnresolvedPermissionCollection$sub_refs	java_security_UnresolvedPermissionCollection;
    _jc_java_security_PermissionCollection$sub_refs	java_security_PermissionCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_UnresolvedPermissionCollection$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_UnresolvedPermissionCollection$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_PermissionCollection$sub_nonrefs	java_security_PermissionCollection;
    _jc_java_security_UnresolvedPermissionCollection$sub_nonrefs	java_security_UnresolvedPermissionCollection;
};

// Object instance structure
struct _jc_java_security_UnresolvedPermissionCollection$object {
	_jc_java_security_UnresolvedPermissionCollection$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_UnresolvedPermissionCollection$vtype	*vtype;
	_jc_java_security_UnresolvedPermissionCollection$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_UnresolvedPermissionCollection$vtype _jc_java_security_UnresolvedPermissionCollection$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_UnresolvedPermissionCollection, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_UnresolvedPermissionCollection$class_object;

#endif	/* _JC_java_security_UnresolvedPermissionCollection_H_ */

==> jc-1.4.6.tar.gz: java/security/UnresolvedPermissionCollection.h <==
// class java.security.UnresolvedPermissionCollection

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c66c17eff6c1d1e6 java_security_PermissionCollection
// @dep_class 5dd1d1276c582d70 java_security_UnresolvedPermissionCollection

// header file dependencies
// @dep_header java_security_PermissionCollection

#include "java/security/PermissionCollection.h"

#ifndef _JC_java_security_UnresolvedPermissionCollection_H_
#define _JC_java_security_UnresolvedPermissionCollection_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_Permission$object;
struct _jc_java_util_Enumeration$object;
struct _jc_java_util_Hashtable$object;

// Typedefs
typedef struct _jc_java_security_UnresolvedPermissionCollection$sub_refs	_jc_java_security_UnresolvedPermissionCollection$sub_refs;
typedef struct _jc_java_security_UnresolvedPermissionCollection$sub_nonrefs	_jc_java_security_UnresolvedPermissionCollection$sub_nonrefs;
typedef struct _jc_java_security_UnresolvedPermissionCollection$refs	_jc_java_security_UnresolvedPermissionCollection$refs;
typedef struct _jc_java_security_UnresolvedPermissionCollection$nonrefs	_jc_java_security_UnresolvedPermissionCollection$nonrefs;
typedef struct _jc_java_security_UnresolvedPermissionCollection$object	_jc_java_security_UnresolvedPermissionCollection$object;

typedef struct _jc_java_security_UnresolvedPermissionCollection$fields_struct	_jc_java_security_UnresolvedPermissionCollection$fields_struct;
typedef const struct _jc_java_security_UnresolvedPermissionCollection$vmethods	_jc_java_security_UnresolvedPermissionCollection$vmethods;
typedef const struct _jc_java_security_UnresolvedPermissionCollection$vtable	_jc_java_security_UnresolvedPermissionCollection$vtable;
typedef const struct _jc_java_security_UnresolvedPermissionCollection$vtype	_jc_java_security_UnresolvedPermissionCollection$vtype;

// Class fields structure
struct _jc_java_security_UnresolvedPermissionCollection$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_UnresolvedPermissionCollection$fields_struct _jc_java_security_UnresolvedPermissionCollection$class_fields;

// Constructors
extern void _jc_java_security_UnresolvedPermissionCollection$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_UnresolvedPermissionCollection$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_security_UnresolvedPermissionCollection$method$add$a94198a5fd6a54ee(_jc_env *, struct _jc_java_security_UnresolvedPermissionCollection$object *, struct _jc_java_security_Permission$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_security_UnresolvedPermissionCollection$method$elements$7e4aa0c44b86c479(_jc_env *, struct _jc_java_security_UnresolvedPermissionCollection$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_security_UnresolvedPermissionCollection$method$implies$cbacf9d54b2bb917(_jc_env *, struct _jc_java_security_UnresolvedPermissionCollection$object *, struct _jc_java_security_Permission$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_UnresolvedPermissionCollection$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_security_UnresolvedPermissionCollection$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_UnresolvedPermissionCollection$method_info$add$a94198a5fd6a54ee;
extern _jc_method _jc_java_security_UnresolvedPermissionCollection$method_info$elements$7e4aa0c44b86c479;
extern _jc_method _jc_java_security_UnresolvedPermissionCollection$method_info$implies$cbacf9d54b2bb917;
extern _jc_method _jc_java_security_UnresolvedPermissionCollection$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_security_UnresolvedPermissionCollection$vmethods {
	void	(*add$a94198a5fd6a54ee)(_jc_env *, struct _jc_java_security_UnresolvedPermissionCollection$object *, struct _jc_java_security_Permission$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*elements$7e4aa0c44b86c479)(_jc_env *, struct _jc_java_security_UnresolvedPermissionCollection$object *) _JC_JCNI_ATTR;
	jboolean	(*implies$cbacf9d54b2bb917)(_jc_env *, struct _jc_java_security_UnresolvedPermissionCollection$object *, struct _jc_java_security_Permission$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_security_UnresolvedPermissionCollection$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_UnresolvedPermissionCollection$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_PermissionCollection$vmethods	java_security_PermissionCollection;
	_jc_java_security_UnresolvedPermissionCollection$vmethods	java_security_UnresolvedPermissionCollection;
};

// Vtype
struct _jc_java_security_UnresolvedPermissionCollection$vtype {
	_jc_type			type;
	_jc_java_security_UnresolvedPermissionCollection$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_UnresolvedPermissionCollection$sub_refs {
	struct _jc_java_util_Hashtable$object	*permissions;
};

// Reference instance fields (object)
struct _jc_java_security_UnresolvedPermissionCollection$refs {
    _jc_java_security_UnresolvedPermissionCollection$sub_refs	java_security_UnresolvedPermissionCollection;
    _jc_java_security_PermissionCollection$sub_refs	java_security_PermissionCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_UnresolvedPermissionCollection$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_UnresolvedPermissionCollection$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_PermissionCollection$sub_nonrefs	java_security_PermissionCollection;
    _jc_java_security_UnresolvedPermissionCollection$sub_nonrefs	java_security_UnresolvedPermissionCollection;
};

// Object instance structure
struct _jc_java_security_UnresolvedPermissionCollection$object {
	_jc_java_security_UnresolvedPermissionCollection$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_UnresolvedPermissionCollection$vtype	*vtype;
	_jc_java_security_UnresolvedPermissionCollection$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_UnresolvedPermissionCollection$vtype _jc_java_security_UnresolvedPermissionCollection$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_UnresolvedPermissionCollection, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_UnresolvedPermissionCollection$class_object;

#endif	/* _JC_java_security_UnresolvedPermissionCollection_H_ */
